@@ -1,3 +1,4 @@
+from .adabins_depth import AdaBinsDepth
 from .blip import BLIP
 from .clip import CLIP
 from .cloob import CLOOB
@@ -7,6 +8,7 @@ from .guided_diffusion import GuidedDiffusion
 from . import latent_diffusion
 from .midas_depth import MidasDepth
 from .monster_diffusion import MonsterDiffusion
+from .owlvit import OWLViT
 from .ruclip import RuCLIP
 from .slip import SLIP
 from .stylegan_xl import StyleGANXL
